idle

package
v0.2.30 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Feb 27, 2026 License: MIT Imports: 4 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func IdleSeconds

func IdleSeconds() (float64, error)

IdleSeconds returns the number of seconds since the last keyboard or mouse input on Linux, using xprintidle (which returns milliseconds).

Types

This section is empty.

Jump to