silent

package
v0.2.30 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Feb 27, 2026 License: MIT Imports: 6 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func Disable

func Disable()

Disable deactivates silent mode by removing the state file.

func Enable

func Enable(d time.Duration)

Enable activates silent mode for the given duration from now.

func IsSilent

func IsSilent() bool

IsSilent returns true if silent mode is currently active. A missing, unreadable, or corrupt state file is treated as "not silent" (fail-open).

func SilentUntil

func SilentUntil() (time.Time, bool)

SilentUntil returns the end time of silent mode and true if active, or zero time and false if not silent.

Types

This section is empty.

Jump to