package
Version:
v0.2.35
Opens a new window with list of versions in this module.
Published: Mar 1, 2026
License: MIT
Opens a new window with license information.
Imports: 3
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
Send posts a message to a Telegram chat via the Bot API.
func SendAudio(token, chatID, wavPath, caption string) error
SendAudio uploads a WAV file to a Telegram chat via the Bot API.
The caption is sent as text alongside the audio file.
func SendVoice(token, chatID, oggPath, caption string) error
SendVoice uploads an OGG/OPUS file to a Telegram chat via the Bot API.
Renders as a native voice bubble in Telegram clients.
Source Files
¶
Click to show internal directories.
Click to hide internal directories.